TensorBoardResultTracker
========================

.. currentmodule:: pykeen.trackers

.. autoclass:: TensorBoardResultTracker
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~TensorBoardResultTracker.end_run
      ~TensorBoardResultTracker.log_metrics
      ~TensorBoardResultTracker.log_params

   .. rubric:: Methods Documentation

   .. automethod:: end_run
   .. automethod:: log_metrics
   .. automethod:: log_params
